@@ -36,8 +36,6 @@ is _only_ text content in this node.
 sub text_only_spec {
   my ($self, $path) = @_;
   my $spec = $self->spec_for_xpath($path);
-  return 1 unless $spec;
-  warn "No spec for $path" unless $spec;
   return 0 if (@{$spec->{elts}} || @{$spec->{attr}});
   return 1;
 }
@@ -57,9 +55,7 @@ sub init_target {
   if (my $spec = $self->spec_for_xpath($path)) {
     for (@{ $spec->{elts} }) {
       # initialize an empty list if we're expecting a list at all
-      my $elt_spec = $self->spec_for_xpath( $path ."/". $_ );
-      next unless $elt_spec;
-      $target->{$_} = [] if $elt_spec->{multi};
+      $target->{$_} = [] if $self->spec_for_xpath( $path ."/". $_ )->{multi};
     }
   }
   return $target;
@@ -68,13 +64,10 @@ sub init_target {
 sub validate_source {
   my ($self, $source, $path) = @_;
   
-  #use Carp; Carp::cluck;
-  
   my $spec = $self->spec_for_xpath($path);
-  my $method = $self->walker->method || '<unknown>';
   
   if (!ref $source) {
-    $logger->warn("Returned unexpected text at '$path' for structure '$method'.")
+    $logger->warn("Returned unexpected text at '$path'.")
       unless $spec->{text};
     return 1;
   }
@@ -86,8 +79,9 @@ sub validate_source {
   }
   delete $keys{-text} if $spec->{text};
   
+  my $method = $self->walker->method || '<unknown>';
   for (keys %keys) {
-    $logger->warn("unknown key '$_' defined within a terse structure at '$path' for structure '$method'.");
+    $logger->warn("unknown key '$_' defined within a terse structure at '$path' for method '$method'.");
   }
   return !keys %keys;
 }
